@@ -527,8 +527,7 @@ npindex.sibandwidth <-
         for (i in ncol(txdat))
           index.gerr[,i] = abs(bws$beta[i])*index.gerr[,i]
 
-
-        index.mgerr = boot.out$t[,2*length(index.eval)+1]
+        index.mgerr = sd(boot.out$t[,2*length(index.eval)+1])
         index.mgerr = abs(bws$beta)*index.mgerr
       }
     }
